@@ -1,5 +1,5 @@
 import click
-from ..globals import MultiCommand
+from ..utils import MultiCommand
 
 @click.group(cls=MultiCommand)
 def manager():
@@ -7,4 +7,8 @@ def manager():
 
 @manager.command("startproject")
 def startproject_command():
-    print("STARTING PROJECT")
\ No newline at end of file
+    print("STARTING PROJECT")
+
+@manager.command("newapp")
+def startproject_command():
+    print("NEW APP")
\ No newline at end of file
